@@ -17,8 +17,7 @@
 **************************************************************************** */
 
 #include "ai_box.h"
-// #include <QStack>
-
+// 
 #include <QDebug>
 #include "stdio.h"
 
@@ -430,4 +429,4 @@ void AI_Box::printBox()
 }
 #endif
 
-#include "ai_box.moc"
+
